[][src]Module bitsy_parser::game

Structs

Game
GameHasNoAvatar
InvalidRoomFormat
InvalidRoomType
InvalidVersion
Version

Enums

NotFound
RoomFormat

in very early versions of Bitsy, room tiles were defined as single alphanumeric characters - so there was a maximum of 36 unique tiles. later versions are comma-separated. RoomFormat is implemented here so we can save in the original format.

RoomType

in very early versions of Bitsy, a room was called a "set"